@@ -3,9 +3,10 @@ use warnings;
 package Graphics::Raylib::Text;
 
 # ABSTRACT: Output text to window
-our $VERSION = '0.008'; # VERSION
+our $VERSION = '0.009'; # VERSION
 
 use Graphics::Raylib::XS qw(:all);
+use Graphics::Raylib::Color;
 
 =pod
 
@@ -18,7 +19,7 @@ Graphics::Raylib::Text - Output text to window
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 SYNOPSIS
 
@@ -62,6 +63,7 @@ sub new {
     my $self = {
         pos => [0,0],
         size => 10,
+        color => Graphics::Raylib::Color::RED,
         @_
     };
 
@@ -69,7 +71,7 @@ sub new {
     return $self;
 }
 
-=item new( text => $text, color => $color, pos => [$x, $y], size => [$width, $height], font => $font, spacing => $spacing )
+=item draw
 
 Constructs a new Graphics::Raylib::Text instance. Position defaults to C<[0,0]> and size to C<10>.
 
@@ -79,8 +81,9 @@ sub draw {
     my $self = shift;
     return $self->{func}() if defined $self->{func};
 
+    return unless defined $self->{text};
     if (defined $self->{font}) {
-        DrawTextEx(
+        DrawTextEx (
             $self->{font}, $self->{text},
             $self->{pos}, $self->{size},
             $self->{spacing}, $self->{color}
@@ -90,9 +93,9 @@ sub draw {
     }
 }
 
-=item new( text => $text, color => $color, pos => [$x, $y], size => [$width, $height], font => $font, spacing => $spacing )
+=item ->text = "Text";
 
-Constructs a new Graphics::Raylib::Text instance. Position defaults to C<[0,0]> and size to C<10>.
+L-value subroutine to change text.
 
 =cut
 
